@@ -43,7 +43,16 @@
 #include <fcntl.h>
 #include <stdio.h>
 #ifndef RANDOM_DEV
+#ifdef TIME_WITH_SYS_TIME
+#include <sys/time.h>
 #include <time.h>
+#else
+#ifdef HAVE_SYS_TIME_H
+#include <sys/time.h>
+#else
+#include <time.h>
+#endif
+#endif
 #endif
 
 #if defined(USE_MODULES) && defined(AS_MODULE)
