@@ -107,14 +107,6 @@ int print_help(int argc, char **argv) {
 	return(0);
 }
 
-int dact_blksize_calc(int fsize) {
-	if (fsize==0) return(DACT_BLK_SIZE_DEF);
-	if (fsize<(204800)) {
-		return(fsize+5);
-	}
-	return(((int) ((((float) fsize)/102400.0)-(0.9999999)))*65535);
-}
-
 int dact_upgrade_file(const char *name, const char *url_get, const char *url_ver, uint32_t version, const char *dest, const char *options) {
 	int newver, ifd=-1, ofd=-1, x=-1;
 	char *real_dest, *real_url_get, buf[4096];
@@ -443,7 +435,6 @@ uint32_t dact_process_other(int src, const int dest, const uint32_t magic, const
  *  -- Roy Keene <dact@rkeene.org>
  */
 	if (lseek_net(src, 0, SEEK_SET)<0) {
-		PRINTERR("This should not be happening.");
 /*
  * lseek_net() should make this obsolete.
  *  ... EXCEPT! when reading from stdin.
@@ -463,7 +454,6 @@ uint32_t dact_process_other(int src, const int dest, const uint32_t magic, const
 	}
 #if defined(HAVE_LIBZ) && defined(HAVE_GZDOPEN)
 
-
 	if ((magic&0xffff0000)==0x1f8b0000) { /* gzip */
 		dact_ui_status(DACT_UI_LVL_GEN, "Gunzipping...");
 		buf=malloc(1024);
@@ -583,7 +573,7 @@ int main(int argc, char **argv) {
 				break;
 			case 'b':
 				i=atoi2(optarg);
-				if (i<DACT_BLK_SIZE_MAX) dact_blk_size=i;
+				if (i<DACT_BLK_SIZE_ABSMAX) dact_blk_size=i;
 				break;
 			case 'v':
 				options[DACT_OPT_VERB]++;
