@@ -24,6 +24,7 @@
 #ifdef HAVE_CONFIG_H
 #include "config.h"
 #endif
+
 #include "win32.h"
 #include "comp_fail.h"
 
@@ -37,8 +38,8 @@
 
 #define DACT_VER_MAJOR 0
 #define DACT_VER_MINOR 8
-#define DACT_VER_REVISION 37
-#define DACT_VERSION "0.8.37"
+#define DACT_VER_REVISION 39
+#define DACT_VERSION "0.8.39"
 #ifdef DEBUG
 #define DACT_VER_SUB	"dev"
 #else
@@ -89,7 +90,11 @@
 #define DACT_HDR_IDXDATA	11
 
 #ifndef DACT_BLK_SIZE_MAX
-#define DACT_BLK_SIZE_MAX 2147483647
+#define DACT_BLK_SIZE_MAX 4194304
+#endif
+
+#ifndef DACT_BLK_SIZE_ABSMAX
+#define DACT_BLK_SIZE_ABSMAX 2147483647
 #endif
 
 #ifndef DACT_BLK_SIZE_DEF
@@ -137,13 +142,7 @@
 #define DACT_MAGIC_SIZE   4
 #define DACT_MAGIC_PEOF   0xFF3FDE08
 
-#define DACT_HDR_REG_SIZE 24
-
 extern char dact_nonetwork;
-struct dact_header {
-	uint32_t size;
-	unsigned char algo;
-};
 
 #if defined(__FILE__) && defined(__LINE__) && defined(DEBUG)
 #define PRINT_LINE fprintf(stderr, "%s:%07i:%s(): ", __FILE__, __LINE__, __func__)
@@ -178,6 +177,10 @@ struct dact_header {
 #define DACT_VER_PARTS(x) ((x&0xff0000)>>16),((x&0xff00)>>8),(x&0xff)
 #endif
 
+#ifndef DACT_VERS
+#define DACT_VERS(x,y,z) (((x)<<16)|((y)<<8)|(z))
+#endif
+
 #ifndef DACT_BIN_URL
 #define DACT_BIN_URL "http://www.rkeene.org/projects/compression/dact/@@OSNM@@-@@ARCH@@/dact.bin"
 #endif
@@ -205,7 +208,6 @@ struct dact_header {
 
 
 int print_help(int argc, char **argv);
-int dact_blksize_calc(int fsize);
 int dact_upgrade_file_checkver(const char *name, const char *url_ver, const char *options);
 int dact_upgrade_file(const char *name, const char *url_get, const char *url_ver, uint32_t version, const char *dest, const char *options);
 int dact_shutdown(int retval);
