@@ -60,6 +60,18 @@
 #include <bzlib.h>
 #endif
 
+uint32_t dact_blksize_calc(int fsize) {
+	uint32_t ret=0;
+
+	if (fsize==0) return(DACT_BLK_SIZE_DEF);
+	if (fsize<(204800)) {
+		ret=(fsize+5);
+	}
+	if (ret==0) ret=(((int) ((((float) fsize)/102400.0)-(0.9999999)))*65535);
+	if (ret>DACT_BLK_SIZE_MAX) ret=DACT_BLK_SIZE_MAX;
+	return(ret);
+}
+
 int dact_config_execute(const char *cmd, char *options, uint32_t *blksize) {
 	char *line=NULL, *line_s, *item_buf[4]={NULL, NULL, NULL, NULL};
 	int i;
@@ -74,7 +86,7 @@ int dact_config_execute(const char *cmd, char *options, uint32_t *blksize) {
 	}
 	if (item_buf[0]==NULL || item_buf[1]==NULL) return(0); /* This means all commands must have arguments. */
 
-	switch (ELFCRC(0, item_buf[0], strlen(item_buf[0]))) {
+	switch (elfcrc(0, item_buf[0], strlen(item_buf[0]))) {
 		case 164209419: /* binary_check */
 			options[DACT_OPT_BINCHK]=!!strcmp(item_buf[1],"off");
 			break;
@@ -126,7 +138,7 @@ int dact_config_execute(const char *cmd, char *options, uint32_t *blksize) {
 			break;
 #ifdef DEBUG
 		default:
-			fprintf(stderr, "Unknown command %s (%i)\n",item_buf[0],ELFCRC(0,item_buf[0],strlen(item_buf[0])));
+			fprintf(stderr, "Unknown command %s (%i)\n",item_buf[0],elfcrc(0,item_buf[0],strlen(item_buf[0])));
 			break;
 #endif
 	}
@@ -231,7 +243,7 @@ uint32_t dact_blk_compress(char *algo, char *ret, const char *srcbuf, const uint
 	return(smallest_size);
 }
 
-uint32_t dact_process_file(const int src, const int dest, const int mode, const char *options, const char *filename, uint32_t *crcs, uint32_t dact_blksize, int cipher) {
+uint64_t dact_process_file(const int src, const int dest, const int mode, const char *options, const char *filename, uint32_t *crcs, uint32_t dact_blksize, int cipher) {
 	struct stat filestats;
 	FILE *extd_urlfile;
 	char *file_extd_urls[256];
@@ -241,8 +253,10 @@ uint32_t dact_process_file(const int src, const int dest, const int mode, const
 	char version[3]={DACT_VER_MAJOR, DACT_VER_MINOR, DACT_VER_REVISION};
 	char file_opts=0;
 	uint32_t bytes_read, retsize;
-	uint32_t filesize=0, blk_cnt=0, file_extd_size=0, blksize=0, fileoutsize=0, out_bufsize=0;
+	uint64_t filesize=0, fileoutsize=0, out_bufsize=0;
+	uint32_t blk_cnt=0, file_extd_size=0, blksize=0, blksize_uncomp=0;
 	uint32_t magic=0, file_extd_read=0, file_extd_urlcnt=0;
+	int hdr_reg_size=28;
 	int blksize_size;
 	int x=0, new_fd, canlseek=0;
 
@@ -279,7 +293,7 @@ uint32_t dact_process_file(const int src, const int dest, const int mode, const
 		write(dest, &version[0], 1);
 		write(dest, &version[1], 1);
 		write(dest, &version[2], 1);
-		write_de(dest, 0, 4); /* Place holder for ORIG FILE SIZE */
+		write_de(dest, 0, 8); /* Place holder for ORIG FILE SIZE */
 		write_de(dest, 0, 4); /* Place holder for NUM BLOCKS */
 		write_de(dest, blksize, 4);
 		write_de(dest, file_opts, 1); /* XXX: Option byte... Or not? */
@@ -324,10 +338,10 @@ uint32_t dact_process_file(const int src, const int dest, const int mode, const
 				dact_ui_status(DACT_UI_LVL_GEN, "Algorithm ");
 				dact_ui_status_append(DACT_UI_LVL_GEN,algorithm_names[algo]);
 
-				crcs[0]=ELFCRC(crcs[0], out_buf, retsize);
-/* Do not generate a CRC of the plaintext if encrypting */
+				crcs[0]=crc(crcs[0], out_buf, retsize);
+				/* Do not generate a CRC of the plaintext if encrypting */
 				if (cipher==-1) {
-					crcs[1]=ELFCRC(crcs[1], in_buf, blksize);
+					crcs[1]=crc(crcs[1], in_buf, blksize);
 				}
 
 				if (!options[DACT_OPT_HDONLY]) {
@@ -357,16 +371,17 @@ uint32_t dact_process_file(const int src, const int dest, const int mode, const
 		free(in_buf);
 		free(out_buf);
 
+		/* Put the filesize and file block count in the header, if possible. */
 		if (lseek_net(dest, 7, SEEK_SET)<0) {
 /* If we can't rewind the stream, put magic+fileisze */
 			write_de(dest, DACT_MAGIC_PEOF, 4);
-			write_de(dest, filesize, 4);
+			write_de(dest, filesize, 8);
 		} else {
-			write_de(dest, filesize, 4);
+			write_de(dest, filesize, 8);
 			write_de(dest, blk_cnt, 4);
 		} 
 
-		if (lseek_net(dest, DACT_HDR_REG_SIZE, SEEK_SET)>0) {
+		if (lseek_net(dest, hdr_reg_size, SEEK_SET)>0) {
 			if (!options[DACT_OPT_NOCRC]) {
 				dact_hdr_ext_regn(DACT_HDR_CRC0, crcs[0], 4);
 				dact_hdr_ext_regn(DACT_HDR_CRC1, crcs[1], 4);
@@ -395,9 +410,19 @@ uint32_t dact_process_file(const int src, const int dest, const int mode, const
 		read(src, &version[0], 1);
 		read(src, &version[1], 1);
 		read(src, &version[2], 1);
-		read_de(src, &filesize, 4, sizeof(filesize));
+#ifndef DACT_DONT_SUPPORT_OLDDACT
+		if (DACT_VERS(version[0], version[1], version[2])<DACT_VERS(0, 8, 39)) {
+			PRINTERR("**WARNING** This file uses the old DACT file header, support will go away in future versions for this.");
+			read_de(src, &filesize, 4, sizeof(filesize));
+			hdr_reg_size=24;
+		} else {
+			read_de(src, &filesize, 8, sizeof(filesize));
+		}
+#else
+		read_de(src, &filesize, 8, sizeof(filesize));
+#endif
 		read_de(src, &blk_cnt, 4, sizeof(blk_cnt));
-		read_de(src, &blksize, 4, sizeof(blksize));
+		read_de(src, &blksize_uncomp, 4, sizeof(blksize_uncomp));
 		read(src, &file_opts, 1);
 		read_de(src, &file_extd_size, 4, sizeof(file_extd_size));
 
@@ -489,7 +514,7 @@ XXX: Todo, make this do something...
 				close(src);
 				crcs[4]=crcs[2];
 				crcs[5]=crcs[3];
-				return(dact_process_file(new_fd, dest, mode, options, filename, crcs, blksize, cipher));
+				return(dact_process_file(new_fd, dest, mode, options, filename, crcs, blksize_uncomp, cipher));
 			}
 		}
 
@@ -506,29 +531,42 @@ XXX: Todo, make this do something...
 /* See if we can rewind our stream, so when we get to the end, we can come back! */
 			if (lseek_net(src, 1, SEEK_SET)==1) { /* MAJOR BUG HERE! was: lseek(src,1,SEEK_SET)==0 which will always be false. */
 				canlseek=1;
-				lseek_net(src, -8, SEEK_END);
+#ifndef DACT_DONT_SUPPORT_OLDDACT
+				if (DACT_VERS(version[0], version[1], version[2])<DACT_VERS(0, 8, 39)) {
+					PRINTERR("**WARNING** This file uses the old DACT file header, support will go away in future versions for this.");
+					lseek_net(src, -8, SEEK_END);
+					read_de(src, &magic, 4, sizeof(magic));
+					read_de(src, &filesize, 4, sizeof(filesize));
+					hdr_reg_size=24;
+				} else {
+					lseek_net(src, -12, SEEK_END);
+					read_de(src, &magic, 4, sizeof(magic));
+					read_de(src, &filesize, 8, sizeof(filesize));
+				}
+#else
+				lseek_net(src, -12, SEEK_END);
 				read_de(src, &magic, 4, sizeof(magic));
+				read_de(src, &filesize, 8, sizeof(filesize));
+#endif
 				if (magic!=DACT_MAGIC_PEOF) {
 					dact_ui_status(DACT_UI_LVL_GEN, "File is corrupt.");
-					return(0);
+					filesize=0;
 				}
-				read_de(src, &filesize, 4, sizeof(filesize));
-				lseek_net(src, DACT_HDR_REG_SIZE+file_extd_size, SEEK_SET);
+				lseek_net(src, hdr_reg_size+file_extd_size, SEEK_SET);
 			} else {
 				canlseek=0;
 			}
 		}
 
-		out_bufsize=blksize;
-		if (((out_buf=malloc(out_bufsize))==NULL) ) {
-				PERROR("malloc");
-				return(0);
+		out_bufsize=blksize_uncomp;
+		if (((out_buf=malloc(out_bufsize))==NULL)) {
+			PERROR("malloc");
+			return(0);
 		}
 
+		blksize_size=BYTESIZE(blksize_uncomp);
 
-		blksize_size=BYTESIZE(blksize);
-
-		dact_ui_setup((int)(((float) filesize/(float) blksize)+0.9999));
+		dact_ui_setup((int)(((float) filesize/(float) blksize_uncomp)+0.9999));
 
 		if (cipher!=-1) {
 			keybuf=malloc(DACT_KEY_SIZE);
@@ -552,7 +590,16 @@ XXX: Todo, make this do something...
 
 			read_f(src, in_buf, blksize);
 
-			crcs[0]=ELFCRC(crcs[0],in_buf,blksize);
+#ifndef DACT_DONT_SUPPORT_OLDDACT
+			if (DACT_VERS(version[0], version[1], version[2])<DACT_VERS(0, 8, 39)) {
+				PRINTERR("**WARNING** This file uses the old DACT file header, support will go away in future versions for this.");
+				crcs[0]=elfcrc(crcs[0],in_buf,blksize);
+			} else {
+				crcs[0]=crc(crcs[0],in_buf,blksize);
+			}
+#else
+			crcs[0]=crc(crcs[0],in_buf,blksize);
+#endif
 
 			if (cipher!=-1) {
 				tmpbuf=malloc(blksize*2);
@@ -598,24 +645,29 @@ XXX: Todo, make this do something...
 			}
 			fileoutsize+=bytes_read;
 
-/* If ciphering, don't try to calculate this CRC. */
+/* If ciphering, don't try to calculate this (the plaintext) CRC. */
 			if (cipher==-1) {
-				crcs[1]=ELFCRC(crcs[1],out_buf,bytes_read);
+#ifndef DACT_DONT_SUPPORT_OLDDACT
+				if (DACT_VERS(version[0], version[1], version[2])<DACT_VERS(0, 8, 39)) {
+					PRINTERR("**WARNING** This file uses the old DACT file header, support will go away in future versions for this.");
+					crcs[1]=elfcrc(crcs[1],out_buf,bytes_read);
+				} else {
+					crcs[1]=crc(crcs[1],out_buf,bytes_read);
+				}
+#else
+				crcs[1]=crc(crcs[1],out_buf,bytes_read);
+#endif
 			}
 
 			dact_ui_incrblkcnt(1);
 
 			if (fileoutsize>filesize && filesize!=0) {
-				write(dest, out_buf, blksize-(fileoutsize-filesize));
+				write(dest, out_buf, blksize_uncomp-(fileoutsize-filesize));
 			} else {
 				write(dest, out_buf, bytes_read);
 			}
 
-
-
 			free(in_buf);
-
-			
 		}
 
 		free(out_buf);
@@ -639,7 +691,17 @@ XXX: Todo, make this do something...
 		read(src, &version[0], 1);
 		read(src, &version[1], 1);
 		read(src, &version[2], 1);
-		read_de(src, &filesize, 4, sizeof(filesize));
+#ifndef DACT_DONT_SUPPORT_OLDDACT
+		if (DACT_VERS(version[0], version[1], version[2])<DACT_VERS(0, 8, 39)) {
+			PRINTERR("**WARNING** This file uses the old DACT file header, support will go away in future versions for this.");
+			read_de(src, &filesize, 4, sizeof(filesize));
+			hdr_reg_size=24;
+		} else {
+			read_de(src, &filesize, 8, sizeof(filesize));
+		}
+#else
+		read_de(src, &filesize, 8, sizeof(filesize));
+#endif
 		read_de(src, &blk_cnt, 4, sizeof(blk_cnt));
 		read_de(src, &blksize, 4, sizeof(blksize));
 		read(src, &file_opts, 1);
@@ -655,12 +717,28 @@ XXX: Todo, make this do something...
 		}
 
 		if (filesize==0) {
-			lseek_net(src, -8, SEEK_END);
-			read_de(src, &magic, 4, sizeof(magic));
-			read_de(src, &filesize, 4, sizeof(filesize));
-			if (magic!=DACT_MAGIC_PEOF) {
-				PRINTERR("Bad magic, corrupt stream.");
-				return(0);
+			if (lseek_net(src, 1, SEEK_SET)==1) {
+#ifndef DACT_DONT_SUPPORT_OLDDACT
+				if (DACT_VERS(version[0], version[1], version[2])<DACT_VERS(0, 8, 39)) {
+					PRINTERR("**WARNING** This file uses the old DACT file header, support will go away in future versions for this.");
+					lseek_net(src, -8, SEEK_END);
+					read_de(src, &magic, 4, sizeof(magic));
+					read_de(src, &filesize, 4, sizeof(filesize));
+					hdr_reg_size=24;
+				} else {
+					lseek_net(src, -12, SEEK_END);
+					read_de(src, &magic, 4, sizeof(magic));
+					read_de(src, &filesize, 8, sizeof(filesize));
+				}
+#else
+				lseek_net(src, -12, SEEK_END);
+				read_de(src, &magic, 4, sizeof(magic));
+				read_de(src, &filesize, 8, sizeof(filesize));
+#endif
+				if (magic!=DACT_MAGIC_PEOF) {
+					PRINTERR("Bad end-of-file magic.  Corrupt or incomplete file?");
+					filesize=0;
+				}
 			}
 		}
 		fileoutsize=lseek_net(src, 0, SEEK_END);
@@ -668,10 +746,10 @@ XXX: Todo, make this do something...
 		printf("Dact Version      :   %i.%i.%i\n",version[0],version[1],version[2]);
 		printf("Block Size        :   %i\n", blksize);
 		printf("Block Header Size :   %i\n", BYTESIZE(blksize)+1);
-		printf("Compressed Size   :   %i\n", fileoutsize);
-		printf("Uncompressed Size :   %i\n", filesize);
+		printf("Compressed Size   :   %llu\n", fileoutsize);
+		printf("Uncompressed Size :   %llu\n", filesize);
 		printf("Ratio             :   %2.3f to 1.0\n", ((float) filesize)/((float) fileoutsize) );
-		lseek_net(src, DACT_HDR_REG_SIZE, SEEK_SET);
+		lseek_net(src, hdr_reg_size, SEEK_SET);
 		while (file_extd_read<file_extd_size) {
 			x=0;
 			read(src, &ch, 1);
@@ -756,7 +834,7 @@ XXX: Todo, make this do something...
 		blk_cnt=0;
 		blksize_size=BYTESIZE(blksize);
 		if (options[DACT_OPT_VERB]) {
-			lseek_net(src, DACT_HDR_REG_SIZE+file_extd_size, SEEK_SET);
+			lseek_net(src, hdr_reg_size+file_extd_size, SEEK_SET);
 			printf("\n");
 			printf("Break down: \n");
 			printf("  Blk | Algo | Size    | Name\n");
