@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2001  Roy Keene
+ * Copyright (C) 2001, 2002, and 2003  Roy Keene
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -25,12 +25,20 @@
 
 int init_modules (void);
 int unload_modules (void);
-int load_module (char *modulename);
+int load_module (char *modulename, const char *options);
+int load_modules_all(const char *options);
 
 #define DACT_MOD_OK 0
 #define DACT_MOD_FAIL (-1)
 
-extern char moduledirectory[128];
+#define DACT_MOD_TYPE_COMP 0
+#define DACT_MOD_TYPE_ENC 1
+
+#define DACT_MOD_REQ_ATLEAST	(0x01000000)
+#define DACT_MOD_REQ_EXACTLY	(0x02000000)
+#define DACT_MOD_REQ_ATMOST	(0x03000000)
+
+extern char moduledirectory[2048];
 extern void *modules[256];
 extern int modules_initialized;
 extern int modules_count;
