@@ -37,17 +37,44 @@
 #include <fcntl.h>
 
 #ifndef NO_NETWORK
+#ifdef HAVE_SYS_SOCKET_H
 #include <sys/socket.h>
+#endif
+#ifdef HAVE_NETINET_IN_H
 #include <netinet/in.h>
+#endif
+#ifdef HAVE_ARPA_INET_H
 #include <arpa/inet.h>
+#endif
+#ifdef HAVE_STDLIB_H
 #include <stdlib.h>
+#endif
+#ifdef HAVE_STRING_H
 #include <string.h>
+#endif
+#ifdef HAVE_NETDB_H
 #include <netdb.h>
+#endif
+#ifdef HAVE_ERRNO_H
 #include <errno.h>
+#endif
+#ifdef HAVE_STDIO_H
 #include <stdio.h>
+#endif
 #include "parse.h"
 #include "crc.h"
 
+#ifndef O_BINARY
+#define O_BINARY 0x0
+#endif
+#ifndef S_IFSOCK
+#define S_IFSOCK 0140000
+#endif
+#ifndef O_LARGEFILE
+#define O_LARGEFILE 0x0
+#endif
+
+
 struct dact_url_info {
 	char *url;
 	int flags;
@@ -86,25 +113,31 @@ int createconnection_tcp(char *host, int port) {
 	struct sockaddr_in sock;
 
 	if (dact_nonetwork) return(-EPERM);
-	if ((hostinfo=gethostbyname(host))==NULL) {
+
 #ifdef HAVE_INET_ATON
-		if (!inet_aton(host,&sock.sin_addr))
+	if (!inet_aton(host,&sock.sin_addr)) {
+#elif HAVE_INET_ADDR
+	if ( (sock.sin_addr.s_addr=inet_addr(host) )==-1) {
 #else
-		if ( (sock.sin_addr.s_addr=inet_addr(host) )==-1)
+	{
 #endif
-			return(-1);
-	} else {
-/* Should we assign here? */
+		if ((hostinfo=gethostbyname(host))==NULL) return(-EPERM);
 		memcpy(&sock.sin_addr.s_addr,hostinfo->h_addr_list[0],hostinfo->h_length);
 	}
+
 	sock.sin_family=AF_INET;
 	sock.sin_port=htons(port);
-	if ((sockid=socket(AF_INET, SOCK_STREAM, 0))<0)
-		return(-1);
-	if (connect(sockid, (struct sockaddr *) &sock, sizeof(sock))<0) {
-		close(sockid);
-		return(-1);
+	if ((sockid=socket(AF_INET, SOCK_STREAM, 0))<0) {
+		CHECKPOINT;
+		return(-EIO);
 	}
+	if (connect(sockid, (struct sockaddr *) &sock, sizeof(sock))<0) {
+		PERROR("connect");
+		CHECKPOINT;
+		close(sockid);
+		return(-EIO);
+	}
+	CHECKPOINT;
 	return(sockid);
 }
 
@@ -118,7 +151,7 @@ int open_net(const char *pathname, int flags, mode_t mode) {
 	if (!parse_url(pathname,scheme,username,password,host,&port,file)) {
 		if ((fd=createconnection_tcp(host,port))<0) return(-1);
 
-		switch (ELFCRC(0, scheme, strlen(scheme))) {
+		switch (elfcrc(0, scheme, strlen(scheme))) {
 			case 457648: /* http */
 				if ((flags&O_WRONLY)==O_WRONLY || (flags&O_RDWR)==O_RDWR) {
 					close(fd);
@@ -198,7 +231,7 @@ int open_net(const char *pathname, int flags, mode_t mode) {
 					read_buf[x]=0;
 
 					while ((smallbuf=strsep(&read_buf,"\n"))!=NULL) {
-						switch (ELFCRC(0, smallbuf, 4)) {
+						switch (elfcrc(0, smallbuf, 4)) {
 							case 231456: /* 550 */
 								if (ftpfd!=-1) close(ftpfd);
 								close(fd);
@@ -268,7 +301,7 @@ int open_net(const char *pathname, int flags, mode_t mode) {
 								break;
 							default:
 #ifdef DEBUG_FTP
-								PRINT_LINE; fprintf(stderr, "dact: Unknown cmd %i (%s)\n",ELFCRC(0,smallbuf,4),smallbuf);
+								PRINT_LINE; fprintf(stderr, "dact: Unknown cmd %i (%s)\n",elfcrc(0,smallbuf,4),smallbuf);
 #endif
 								break;
 						}
@@ -283,7 +316,7 @@ int open_net(const char *pathname, int flags, mode_t mode) {
 		free(read_buf_s);
 		close(fd);
 	} else {
-		fd=open(pathname,flags,mode);
+		fd=open(pathname,flags|O_BINARY|O_LARGEFILE,mode);
 		if (dact_urls[fd].url!=NULL) free(dact_urls[fd].url);
 		dact_urls[fd].url=strdup(pathname);
 		dact_urls[fd].flags=flags;
@@ -296,36 +329,73 @@ int open_net(const char *pathname, int flags, mode_t mode) {
 
 off_t lseek_net(int filedes, off_t offset, int whence) {
 	struct stat file_status;
+	char tmpbuf[1024];
+	off_t retval, rset=0, i;
+	size_t n;
+	ssize_t read_val;
 	int newfd;
 
 	fstat(filedes, &file_status);
-	if (S_ISSOCK(file_status.st_mode)) {
-		if (whence==SEEK_END) return(-1);
-		if (offset!=0 || whence!=SEEK_SET) return(-1); /* For now ... */
-		if (dact_urls[filedes].url==NULL) return(-1);
-		if ((newfd=open_net(dact_urls[filedes].url,dact_urls[filedes].flags,dact_urls[filedes].mode))<0) return(-1);
-		close(filedes);
-		dup2(newfd,filedes);
-		return(0);
+	if ((file_status.st_mode&S_IFSOCK)==S_IFSOCK) {
+		if (whence!=SEEK_CUR || offset<=0) {
+			if (whence!=SEEK_SET) return(-1); /* For now ... */
+			if (dact_urls[filedes].url==NULL) return(-1);
+			if ((newfd=open_net(dact_urls[filedes].url,dact_urls[filedes].flags,dact_urls[filedes].mode))<0) return(-1);
+			close(filedes);
+			dup2(newfd,filedes);
+			if (offset==0) return(0);
+		}
+	} else {
+		retval=lseek(filedes, offset, whence);
+		if (!(retval<0 && whence==SEEK_CUR && offset>0)) {
+			return(retval);
+		}
 	}
-	return(lseek(filedes,offset,whence));
+
+	retval=0;
+	for (i=0; i<offset; i++) {
+		n=offset-rset;
+		if (n>sizeof(tmpbuf)) n=sizeof(tmpbuf);
+		read_val=read(filedes, tmpbuf, n);
+		if (read_val<=0) { retval=-1; break; }
+		rset+=read_val;
+	}
+	retval=offset+1;
+	return(retval);
 }
 
 #else
+#ifndef O_BINARY
+#define O_BINARY 0x0
+#endif
+#ifndef O_LARGEFILE
+#define O_LARGEFILE 0x0
+#endif
+
 int createlisten(int port) { return(-1); }
 void closeconnection(int sockfd) { return; }
 int createconnection_tcp(char *host, int port) { return(-1); }
-int open_net(const char *pathname, int flags,...) {
-	va_list args;
-	mode_t mode;
-
-	va_start(args, flags);
-	mode = va_arg(args, mode_t);
-	va_end(args);
-
-	return(open(pathname,flags,mode));
+int open_net(const char *pathname, int flags, mode_t mode) {
+	return(open(pathname,flags|O_BINARY|O_LARGEFILE,mode));
 }
 off_t lseek_net(int filedes, off_t offset, int whence) {
-	return(lseek(filedes,offset,whence));
+	char tmpbuf[1024];
+	off_t retval, rset=0, i;
+	size_t n;
+	ssize_t read_val;
+
+	retval=lseek(filedes, offset, whence);
+	if (retval<0 && whence==SEEK_CUR && offset>0) {
+		retval=0;
+		for (i=0; i<offset; i++) {
+			n=offset-rset;
+			if (n>sizeof(tmpbuf)) n=sizeof(tmpbuf);
+			read_val=read(filedes, tmpbuf, n);
+			if (read_val<=0) { retval=-1; break; }
+			rset+=read_val;
+		}
+		retval=offset+1;
+	}
+	return(retval);
 }
 #endif
