@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2001  Roy Keene
+ * Copyright (C) 2001, 2002, and 2003  Roy Keene
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -33,6 +33,6 @@ char *parse_url_subst_dist(void);
 char *mime64(unsigned char *str);
 char *mimes64(unsigned char *str, int *size);
 char *demime64(unsigned char *str);
-ssize_t read_f(int fd, void *buf, size_t count);
+int32_t read_f(int fd, void *buf, size_t count);
 uint32_t hash_fourbyte(unsigned char *str, const char term);
 #endif
